@@ -28,7 +28,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes.
  *
- * $Id: gedit-session.c,v 1.12 2006/03/14 10:53:10 pborelli Exp $
+ * $Id: gedit-session.c 4903 2006-05-22 15:53:10Z pborelli $
  */
 
 
@@ -605,9 +605,6 @@ client_die_cb (GnomeClient *client, gpointer data)
 
 	gedit_debug_message (DEBUG_FILE, "Unref gedit_app_server: DONE");
 #endif
-	gedit_prefs_manager_app_shutdown ();
-	gedit_metadata_manager_shutdown ();
-	gedit_plugins_engine_shutdown ();
 
 	gtk_main_quit ();
 }
